InfiniSDK
=========


|                       |                                                                                    |
|-----------------------|------------------------------------------------------------------------------------|
| Build Status          | ![Build Status](https://secure.travis-ci.org/Infinidat/infinisdk.png?branch=master) |
| Supported Versions    | ![Supported Versions](https://img.shields.io/pypi/pyversions/infinisdk.svg)    |
| Latest Version        | ![Latest Version](https://img.shields.io/pypi/v/infinisdk.svg)                  |

Overview
--------

InfiniSDK is the official Python SDK for INFINIDAT's products.  It provides a clean interface for creating, deleting, querying and manipulating API objects.


* [Infinidat Homepage](https://www.infinidat.com)

* [InfiniSDK Documentation](https://infinisdk.readthedocs.org/)


Licence
-------
BSD-3

